@@ -14,7 +14,7 @@ use App::txtnix::Registry;
 use IO::Pager;
 use Mojo::ByteStream 'b';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 has ua      => sub { shift->_build_ua };
 has cache   => sub { App::txtnix::Cache->new( cache_dir => shift->cache_dir ) };
@@ -36,7 +36,9 @@ has since             => sub { Mojo::Date->new->epoch(0) };
 has until             => sub { Mojo::Date->new() };
 has ca_file           => sub { '/etc/ssl/certs/ca-certificates.crt' };
 
-has [qw( twturl pre_tweet_hook post_tweet_hook config force registry )];
+has [
+    qw( twturl pre_tweet_hook post_tweet_hook config force registry key_file cert_file )
+];
 
 sub new {
     my ( $class, @args ) = @_;
@@ -91,7 +93,8 @@ sub _build_ua {
     $ua->transactor->name($ua_string);
     $ua->proxy->detect;
     $ua->ca( $self->ca_file );
-
+    $ua->cert( $self->cert_file ) if $self->cert_file;
+    $ua->key( $self->key_file )   if $self->key_file;
     return $ua;
 }
 
@@ -144,6 +147,7 @@ sub get_tweets {
     my @tweets;
 
     my @urls = $source || values %{ $self->following };
+    my %urls = map { $_ => 1 } @urls;
 
     my $delay = Mojo::IOLoop->delay;
 
@@ -222,6 +226,7 @@ sub get_tweets {
                 for my $result (@results) {
                     my ( $nick, $url ) =
                       $result->[0] =~ /\@<(?:(\w+) )?([^>]+)>/;
+                    next if $url and $urls{$url};
                     my $source =
                       App::txtnix::Source->new( url => $url, nick => $nick );
                     my $timestamp = $self->to_date( $result->[1] );
@@ -256,7 +261,7 @@ sub get_tweets {
           if $self->use_cache;
     }
 
-    return $self->filter_tweets(@tweets);
+    return @tweets;
 }
 
 sub filter_tweets {
@@ -373,6 +378,11 @@ sub collapse_mention {
     return $nick ? "\@$nick" : $user ? "\@<$user $url>" : "\@<$url>";
 }
 
+sub parse_mention {
+    my ( $self, $text ) = @_;
+    return $text =~ /\@<(?:(\w+) )?([^>]+)>/;
+}
+
 sub known_users {
     my $self = shift;
     if ( $self->nick and $self->twturl ) {
