@@ -100,6 +100,11 @@ opt until => (
     comment => 'Only display tweets written until the supplied datetime.',
     alias   => 'u',
 );
+opt me => (
+    isa     => 'Bool',
+    comment => 'Only display your tweets and all replies and mentions.',
+    alias   => 'm',
+);
 
 subcmd
   cmd     => 'view',
@@ -246,7 +251,7 @@ arg key => (
 
 subcmd
   cmd     => 'query',
-  comment => 'Query your regsitry.';
+  comment => 'Query your registry.';
 
 arg command => (
     isa      => 'SubCmd',
@@ -269,4 +274,42 @@ opt limit => (
     alias   => 'l',
 );
 
+opt unfollowed => (
+    isa     => 'Bool',
+    comment => 'Only list users you are not already following.',
+);
+
+subcmd
+  cmd     => [qw( query mentions)],
+  comment => 'Query registry for mentions.';
+
+arg search_term => (
+    isa      => 'Str',
+    comment  => 'Search term.',
+    required => 1,
+);
+
+subcmd
+  cmd     => [qw( query tags)],
+  comment => 'Query registry for tags.';
+
+arg search_term => (
+    isa      => 'Str',
+    comment  => 'Search term.',
+    required => 1,
+);
+
+subcmd
+  cmd     => [qw( query tweets)],
+  comment => 'Query registry for tweets.';
+
+arg search_term => (
+    isa     => 'Str',
+    comment => 'Search term.',
+);
+
+subcmd
+  cmd     => 'register',
+  comment => 'Register at your registry.';
+
 1;
